==> foundry_platform_sdk-0.23.0.tar.gz: foundry_platform_sdk-0.23.0/foundry/v1/ontologies/models/_list_object_types_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

from pydantic import BaseModel
from pydantic import Field

from foundry.v1.core.models._page_token import PageToken
from foundry.v1.ontologies.models._list_object_types_response_dict import (
    ListObjectTypesResponseDict,
)  # NOQA
from foundry.v1.ontologies.models._object_type import ObjectType


class ListObjectTypesResponse(BaseModel):
    """ListObjectTypesResponse"""

    next_page_token: Optional[PageToken] = Field(alias="nextPageToken", default=None)

    data: List[ObjectType]
    """The list of object types in the current page."""

    model_config = {"extra": "allow"}

    def to_dict(self) -> ListObjectTypesResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(ListObjectTypesResponseDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.28.0.tar.gz: foundry_platform_sdk-0.28.0/foundry/v1/ontologies/models/_list_object_types_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

import pydantic

from foundry.v1.core.models._page_token import PageToken
from foundry.v1.ontologies.models._list_object_types_response_dict import (
    ListObjectTypesResponseDict,
)  # NOQA
from foundry.v1.ontologies.models._object_type import ObjectType


class ListObjectTypesResponse(pydantic.BaseModel):
    """ListObjectTypesResponse"""

    next_page_token: Optional[PageToken] = pydantic.Field(alias="nextPageToken", default=None)

    data: List[ObjectType]
    """The list of object types in the current page."""

    model_config = {"extra": "allow"}

    def to_dict(self) -> ListObjectTypesResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(ListObjectTypesResponseDict, self.model_dump(by_alias=True, exclude_unset=True))
